@@ -4,8 +4,8 @@ The decorator exposes the possibility to create a new decorator to an existing f
 
 """
 from functools import update_wrapper
-from typing import Callable, ClassVar
-from injectable import autowired
+from typing import Callable
+from injectable import autowired, Autowired
 from chain.core.domains.state import State
 from chain.core.domains.chain import Chain
 
@@ -19,6 +19,10 @@ class Decorator(Chain):
     """
 
     @autowired
-    def __init__(self, function: Callable, *, initial_state: State) -> ClassVar:
+    def __init__(
+        self,
+        function: Callable,
+        initial_state: Autowired(State, namespace="python-chain"),
+    ):
         super().__init__(function, initial_state=initial_state)
         update_wrapper(self, function)
